@@ -2,7 +2,7 @@ use 5.14.0;
 
 package Dist::Zilla::MintingProfile::MapMetro::Map;
 
-our $VERSION = '0.1401'; # VERSION
+our $VERSION = '0.1402'; # VERSION
 # ABSTRACT: Mint a Map::Metro Map distribution
 
 use Moose;
@@ -22,7 +22,7 @@ Dist::Zilla::MintingProfile::MapMetro::Map - Mint a Map::Metro Map distribution
 
 =head1 VERSION
 
-Version 0.1401, released 2015-01-13.
+Version 0.1402, released 2015-01-29.
 
 =head1 SYNOPSIS
 
@@ -42,11 +42,11 @@ L<Task::MapMetro::Dev>
 
 =head1 SOURCE
 
-L<https://github.com/Csson/p5-Dist-Zilla-MintingProfile-MapMetro-Map>
+Source repository is at L<https://github.com/Csson/p5-Dist-Zilla-MintingProfile-MapMetro-Map>.
 
 =head1 HOMEPAGE
 
-L<https://metacpan.org/release/Dist-Zilla-MintingProfile-MapMetro-Map>
+Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla-MintingProfile-MapMetro-Map>.
 
 =head1 AUTHOR
 
