@@ -2,7 +2,7 @@ use 5.14.0;
 
 package Dist::Zilla::Plugin::MapMetro::MintMapFiles;
 
-our $VERSION = '0.1401'; # VERSION
+our $VERSION = '0.1402'; # VERSION
 
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
@@ -39,15 +39,15 @@ Dist::Zilla::Plugin::MapMetro::MintMapFiles
 
 =head1 VERSION
 
-Version 0.1401, released 2015-01-13.
+Version 0.1402, released 2015-01-29.
 
 =head1 SOURCE
 
-L<https://github.com/Csson/p5-Dist-Zilla-MintingProfile-MapMetro-Map>
+Source repository is at L<https://github.com/Csson/p5-Dist-Zilla-MintingProfile-MapMetro-Map>.
 
 =head1 HOMEPAGE
 
-L<https://metacpan.org/release/Dist-Zilla-MintingProfile-MapMetro-Map>
+Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla-MintingProfile-MapMetro-Map>.
 
 =head1 AUTHOR
 
